@@ -1,4 +1,4 @@
-class LinkNotFoundError(BaseException):
+class LinkNotFoundError(Exception):
     """Exception raised when mechanicalsoup fails to find something.
 
     This happens in situations like (non-exhaustive list):
@@ -14,3 +14,10 @@ class LinkNotFoundError(BaseException):
       StatefulBrowser).
     """
     pass
+
+
+def is_multipart_file_upload(form, tag):
+    return (
+        form.get("enctype", "") == "multipart/form-data" and
+        tag.get("type", "").lower() == "file"
+    )
